@@ -5,9 +5,8 @@ import pandas as pd
 import pathlib
 
 
-def download_cute_dataset():
-    """Downloads torchvision.datasets.Caltech101 into torch.hub.get_dir().
-    
+def load_cute_dataset(root):
+    """
     Returns pd.Dataframe with metadata for CuteDataset.
     
     Cuteness column is randomized in a small degree.
@@ -21,11 +20,7 @@ def download_cute_dataset():
     }
     name_to_label = {k: i for i, k in enumerate(map_cuteness.keys())}
 
-    root = torch.hub.get_dir()
     root = pathlib.Path(root).expanduser()
-
-    # download Caltech Dataset
-    torchvision.datasets.Caltech101(root, download=True)
     
     files = [d_path.relative_to(root) for d_path in root.rglob("*.jpg")]
     files = [f for f in files if f.parent.name in map_cuteness] # only 5 labels
@@ -40,4 +35,4 @@ def download_cute_dataset():
 
     df = pd.DataFrame(data=zip(file_names, label_names, labels, cuteness), columns=["file_name", "label_name", "label", "cuteness"])
     
-    return df, root / 'caltech101/101_ObjectCategories'
\ No newline at end of file
+    return df
\ No newline at end of file
